@@ -15,4 +15,4 @@ from .auth import (Auth, CREDENTIAL_LOGIN, CREDENTIAL_PASSWORD,
     CREDENTIAL_TOKEN, UserExistsError, UserDoesNotExistsError,
     PasswordTooShortError)
 from .perms import protected, is_valid, invalid_csrf_secret
-from .utils import get_user_model
+from .utils import get_user_model, LazyUser, Token
