@@ -262,12 +262,25 @@ class Auth(object):
         request.__class__.user = self.LazyUser(self.db, self.User)
     
     def get_urls(self):
-        urls = [
-            Rule(self.settings.sign_in_url, self.sign_in_view,
-                name='auth.sign_in'),
-            Rule(self.settings.sign_out_url, self.sign_out_view,
-                name='auth.sign_out'),
-            ]
+        urls = []
+
+        sign_in_url = self.settings.sign_in_url
+        if sign_in_url.startswith('/'):
+            rule = Rule(sign_in_url, self.sign_in_view,
+                name='auth.sign_in')
+        else:
+            rule = Rule('/sign-in/', redirect_to=sign_in_url,
+                name='auth.sign_in')
+        urls.append(rule)
+        
+        sign_out_url = self.settings.sign_out_url
+        if sign_out_url.startswith('/'):
+            rule = Rule(sign_out_url, self.sign_out_view,
+                name='auth.sign_out')
+        else:
+            rule = Rule('/sign_out/', redirect_to=sign_out_url,
+                name='auth.sign_out')
+        urls.append(rule)
         
         if self.settings.password_change:
             urls.extend([
